@@ -11,8 +11,8 @@ class PrintMethod(NotifyMethods):
         super().__init__(*args, **kwargs)
 
     def _set_credentials(self, verbose: bool=True, *args, **kwargs):
-        self.verbose = self.type_or_env(verbose, "VERBOSE", bool)
-        
-    def send_message(self, MSG: str):
+        self.verbose = self._type_or_env(verbose, "VERBOSE", bool)
+        """Whether to print to the console or not"""        
+    def _send_message(self, MSG: str):
         if self.verbose:
             print(MSG)
